@@ -1,7 +1,7 @@
 package Bencher::Formatter::RoundNumbers;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use 5.010001;
 use strict;
@@ -23,7 +23,7 @@ sub munge_result {
         # 1/'rate' here
         my $num_significant_digits =
             $rit->{errors} == 0 ? 6 :
-            POSIX::round(log( abs(1/$rit->{rate}) / $rit->{errors})/log(10));
+            sprintf("%d", log( abs(1/$rit->{rate}) / $rit->{errors})/log(10));
         my $fmt = "%.${num_significant_digits}g";
         $rit->{time} = sprintf($fmt, $rit->{time});
         if (exists $rit->{rate}) {
@@ -52,7 +52,7 @@ Bencher::Formatter::RoundNumbers - Round numbers (rate, time) to certain signifi
 
 =head1 VERSION
 
-This document describes version 0.33 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher), released on 2016-01-22.
+This document describes version 0.34 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher), released on 2016-01-22.
 
 =for Pod::Coverage .*
 
